/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.output.stream.container.internal;

import com.liferay.portal.kernel.util.StreamUtil;
import com.liferay.portal.output.stream.container.OutputStreamContainer;
import com.liferay.portal.output.stream.container.OutputStreamContainerFactory;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;

import java.nio.file.Files;
import java.nio.file.Path;

import org.osgi.service.component.annotations.Component;

/**
 * @author Carlos Sierra Andrés
 */
@Component(immediate = true, property = "name=temp_file")
public class TempFileOutputStreamContainerFactory
	implements OutputStreamContainerFactory {

	@Override
	public OutputStreamContainer create(String hint) {
		try {
			Path tempDirectoryPath = Files.createTempDirectory(
				"com_liferay_portal_output_stream_container_internal_" +
					"TempFileOutputStreamContainerFactory");

			final Path tempFilePath = Files.createTempFile(
				tempDirectoryPath, hint, ".log");

			return new OutputStreamContainer() {

				@Override
				public String getDescription() {
					Path absolutePath = tempFilePath.toAbsolutePath();

					return absolutePath.toString();
				}

				@Override
				public OutputStream getOutputStream() {
					try {
						return StreamUtil.uncloseable(
							new FileOutputStream(tempFilePath.toFile()));
					}
					catch (FileNotFoundException fnfe) {
						throw new RuntimeException(fnfe);
					}
				}

			};
		}
		catch (IOException ioe) {
			throw new RuntimeException(ioe);
		}
	}

}